import React from 'react';

function _typeof(obj) {
  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  }
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArray(iter) {
  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}

function _iterableToArrayLimit(arr, i) {
  if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
    return;
  }

  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance");
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var queries = [];
var cancelledError = {};
var globalStateListeners = [];
var uid = 0; // Focus revalidate

var eventsBinded = false;

if (typeof window !== 'undefined' && !eventsBinded) {
  var revalidate = function revalidate() {
    var refetchAllOnWindowFocus = defaultConfig.refetchAllOnWindowFocus;
    if (refetchAllOnWindowFocus && isDocumentVisible() && isOnline()) refetchAllQueries();
  };

  window.addEventListener('visibilitychange', revalidate, false);
  window.addEventListener('focus', revalidate, false);
  eventsBinded = true;
}

var defaultConfig = {
  retry: 3,
  retryDelay: function retryDelay(attemptIndex) {
    return Math.min(1000 * Math.pow(2, attemptIndex), 30000);
  },
  cacheTime: 10 * 1000,
  inactiveCacheTime: 10 * 1000,
  queryAutoRefetch: false,
  refetchAllOnWindowFocus: true,
  autoRefetch: false
};
function useReactQueryConfig() {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  Object.assign(defaultConfig, config);
}

function makeQuery(_ref) {
  var queryHash = _ref.queryHash,
      queryGroup = _ref.queryGroup,
      variablesHash = _ref.variablesHash,
      variables = _ref.variables,
      config = _ref.config,
      queryFn = _ref.queryFn;
  var query = {
    queryHash: queryHash,
    queryGroup: queryGroup,
    variablesHash: variablesHash,
    variables: variables,
    promise: null,
    previousDelay: 0,
    cacheTimeout: null,
    inactiveCacheTimeout: null,
    cancelled: null,
    state: {
      data: null,
      error: null,
      isFetching: false,
      failureCount: 0,
      isCached: false,
      isStale: true
    },
    instances: []
  };

  query.setState = function (updater) {
    query.state = typeof updater === 'function' ? updater(query.state) : updater;
    query.instances.forEach(function (instance) {
      instance.onStateUpdate(query.state);
    });
    globalStateListeners.forEach(function (d) {
      return d();
    });
  };

  query.subscribe = function (instance) {
    var found = query.instances.find(function (d) {
      return d.id === instance.id;
    });

    if (found) {
      Object.assign(found, instance);
    } else {
      found = instance;
      query.instances.push(instance);
    } // Mark as inactive


    query.setState(function (old) {
      return _objectSpread2({}, old, {
        isInactive: false
      });
    }); // Cancel garbage collection

    clearTimeout(query.inactiveCacheTimeout); // Mark the query as not cancelled

    query.cancelled = null; // Return the unsubscribe function

    return function () {
      query.instances = query.instances.filter(function (d) {
        return d.id !== instance.id;
      });

      if (!query.instances.length) {
        // Cancel any side-effects
        query.cancelled = cancelledError; // Mark as inactive

        query.setState(function (old) {
          return _objectSpread2({}, old, {
            isInactive: true
          });
        }); // Schedule garbage collection

        query.inactiveCacheTimeout = setTimeout(function () {
          queries.splice(queries.findIndex(function (d) {
            return d === query;
          }), 1);
          globalStateListeners.forEach(function (d) {
            return d();
          });
        }, query.state.isCached ? config.inactiveCacheTime : 0);
      }
    };
  }; // Set up the fetch function


  var tryFetchQuery =
  /*#__PURE__*/
  function () {
    var _ref2 = _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee2() {
      var data, delay;
      return regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.prev = 0;
              _context2.next = 3;
              return queryFn(query.variables);

            case 3:
              data = _context2.sent;

              if (!query.cancelled) {
                _context2.next = 6;
                break;
              }

              throw query.cancelled;

            case 6:
              return _context2.abrupt("return", data);

            case 9:
              _context2.prev = 9;
              _context2.t0 = _context2["catch"](0);

              if (!query.cancelled) {
                _context2.next = 13;
                break;
              }

              throw query.cancelled;

            case 13:
              // If we fail, increase the failureCount
              query.setState(function (old) {
                return _objectSpread2({}, old, {
                  failureCount: old.failureCount + 1
                });
              }); // Do we need to retry the request?

              if (!( // Only retry if the document is visible
              config.retry === true || query.state.failureCount < config.retry)) {
                _context2.next = 19;
                break;
              }

              if (isDocumentVisible()) {
                _context2.next = 17;
                break;
              }

              return _context2.abrupt("return", new Promise(function (r) {}));

            case 17:
              // Determine the retryDelay
              delay = typeof config.retryDelay === 'function' ? config.retryDelay(query.state.failureCount) : config.retryDelay; // Return a new promise with the retry

              return _context2.abrupt("return", new Promise(function (resolve, reject) {
                // Keep track of the retry timeout
                setTimeout(
                /*#__PURE__*/
                _asyncToGenerator(
                /*#__PURE__*/
                regeneratorRuntime.mark(function _callee() {
                  var _data;

                  return regeneratorRuntime.wrap(function _callee$(_context) {
                    while (1) {
                      switch (_context.prev = _context.next) {
                        case 0:
                          if (!query.cancelled) {
                            _context.next = 2;
                            break;
                          }

                          return _context.abrupt("return", reject(query.cancelled));

                        case 2:
                          _context.prev = 2;
                          _context.next = 5;
                          return tryFetchQuery();

                        case 5:
                          _data = _context.sent;

                          if (!query.cancelled) {
                            _context.next = 8;
                            break;
                          }

                          return _context.abrupt("return", reject(query.cancelled));

                        case 8:
                          resolve(_data);
                          _context.next = 16;
                          break;

                        case 11:
                          _context.prev = 11;
                          _context.t0 = _context["catch"](2);

                          if (!query.cancelled) {
                            _context.next = 15;
                            break;
                          }

                          return _context.abrupt("return", reject(query.cancelled));

                        case 15:
                          reject(_context.t0);

                        case 16:
                        case "end":
                          return _context.stop();
                      }
                    }
                  }, _callee, null, [[2, 11]]);
                })), delay);
              }));

            case 19:
              throw _context2.t0;

            case 20:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, null, [[0, 9]]);
    }));

    return function tryFetchQuery() {
      return _ref2.apply(this, arguments);
    };
  }();

  query.fetch =
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee4() {
    var _ref5,
        merge,
        force,
        _args4 = arguments;

    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _ref5 = _args4.length > 0 && _args4[0] !== undefined ? _args4[0] : {}, merge = _ref5.merge, force = _ref5.force;

            if (!(!query.state.isStale && !force)) {
              _context4.next = 3;
              break;
            }

            return _context4.abrupt("return");

          case 3:
            // Create a new promise for the query cache if necessary
            if (!query.promise) {
              query.promise = _asyncToGenerator(
              /*#__PURE__*/
              regeneratorRuntime.mark(function _callee3() {
                var data;
                return regeneratorRuntime.wrap(function _callee3$(_context3) {
                  while (1) {
                    switch (_context3.prev = _context3.next) {
                      case 0:
                        // If there are any retries pending for this query, kill them
                        query.cancelled = null;
                        _context3.prev = 1;
                        // Set up the query refreshing state
                        query.setState(function (old) {
                          return _objectSpread2({}, old, {
                            error: null,
                            isFetching: true,
                            failureCount: 0
                          });
                        }); // Try to fetch

                        _context3.next = 5;
                        return tryFetchQuery();

                      case 5:
                        data = _context3.sent;
                        // Set data and mark it as cached
                        query.setState(function (old) {
                          return _objectSpread2({}, old, {
                            data: merge ? merge(old.data, data) : data,
                            isCached: true,
                            isStale: false
                          });
                        });
                        return _context3.abrupt("return", data);

                      case 10:
                        _context3.prev = 10;
                        _context3.t0 = _context3["catch"](1);

                        if (!(_context3.t0 !== query.cancelled)) {
                          _context3.next = 15;
                          break;
                        }

                        // Store the error
                        query.setState(function (old) {
                          return _objectSpread2({}, old, {
                            error: _context3.t0,
                            isCached: false,
                            isStale: true
                          });
                        });
                        throw _context3.t0;

                      case 15:
                        _context3.prev = 15;
                        // Schedule a fresh invalidation, always!
                        query.cacheTimeout = setTimeout(function () {
                          if (query) {
                            query.setState(function (old) {
                              return _objectSpread2({}, old, {
                                isStale: true
                              });
                            });

                            if (config.autoRefetch) {
                              fetch();
                            }
                          }
                        }, config.cacheTime);
                        query.setState(function (old) {
                          return _objectSpread2({}, old, {
                            isFetching: false
                          });
                        });
                        delete query.promise;
                        return _context3.finish(15);

                      case 20:
                      case "end":
                        return _context3.stop();
                    }
                  }
                }, _callee3, null, [[1, 10, 15, 20]]);
              }))();
            }

            return _context4.abrupt("return", query.promise);

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));

  query.setData = function (updater) {
    return query.setState(function (old) {
      return _objectSpread2({}, old, {
        data: typeof updater === 'function' ? updater(old.data) : updater
      });
    });
  };

  return query;
}

function useQuery(queryKey, queryFn) {
  var config = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var instanceIdRef = React.useRef(uid++);
  var instanceId = instanceIdRef.current;
  config = _objectSpread2({}, defaultConfig, {}, config);
  var _config = config,
      manual = _config.manual;

  var _getQueryInfo = getQueryInfo(queryKey),
      _getQueryInfo2 = _slicedToArray(_getQueryInfo, 4),
      queryHash = _getQueryInfo2[0],
      queryGroup = _getQueryInfo2[1],
      variablesHash = _getQueryInfo2[2],
      variables = _getQueryInfo2[3];

  var query = queries.find(function (query) {
    return query.queryHash === queryHash;
  });

  if (query) {
    query.config = config;
    query.queryFn = queryFn;
  } else {
    query = makeQuery({
      queryHash: queryHash,
      queryGroup: queryGroup,
      variablesHash: variablesHash,
      variables: variables,
      config: config,
      queryFn: queryFn
    });
    queries.push(query);
  }

  var _React$useState = React.useState(query.state),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      state = _React$useState2[0],
      setState = _React$useState2[1];

  var onStateUpdate = React.useCallback(function (newState) {
    return setState(newState);
  }, []);
  React.useEffect(function () {
    var unsubscribeFromQuery = query.subscribe({
      id: instanceId,
      onStateUpdate: onStateUpdate
    });
    return unsubscribeFromQuery;
  }, [instanceId, onStateUpdate, query]);
  var isLoading = !queryHash || manual ? false : state.isCached ? false : true;
  var refetch = query.fetch;
  var getLatestManual = useGetLatest(manual);
  React.useEffect(function () {
    if (getLatestManual()) {
      return;
    }

    var runRefetch =
    /*#__PURE__*/
    function () {
      var _ref7 = _asyncToGenerator(
      /*#__PURE__*/
      regeneratorRuntime.mark(function _callee5() {
        return regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                _context5.prev = 0;
                _context5.next = 3;
                return query.fetch();

              case 3:
                _context5.next = 8;
                break;

              case 5:
                _context5.prev = 5;
                _context5.t0 = _context5["catch"](0);
                console.error(_context5.t0); // Swallow this error. Don't rethrow it into a render function

              case 8:
              case "end":
                return _context5.stop();
            }
          }
        }, _callee5, null, [[0, 5]]);
      }));

      return function runRefetch() {
        return _ref7.apply(this, arguments);
      };
    }();

    runRefetch();
  }, [getLatestManual, query, queryHash]);
  return _objectSpread2({}, state, {
    isLoading: isLoading,
    refetch: refetch,
    setData: query.setData
  });
}
function refetchQuery(_x) {
  return _refetchQuery.apply(this, arguments);
}

function _refetchQuery() {
  _refetchQuery = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee8(userQueryKey) {
    var _ref8,
        force,
        _getQueryInfo5,
        _getQueryInfo6,
        queryGroup,
        variablesHash,
        variables,
        queryPromises,
        _args8 = arguments;

    return regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            _ref8 = _args8.length > 1 && _args8[1] !== undefined ? _args8[1] : {}, force = _ref8.force;
            _getQueryInfo5 = getQueryInfo(userQueryKey), _getQueryInfo6 = _slicedToArray(_getQueryInfo5, 4), queryGroup = _getQueryInfo6[1], variablesHash = _getQueryInfo6[2], variables = _getQueryInfo6[3];

            if (queryGroup) {
              _context8.next = 4;
              break;
            }

            return _context8.abrupt("return");

          case 4:
            queryPromises = queries.map(
            /*#__PURE__*/
            function () {
              var _ref15 = _asyncToGenerator(
              /*#__PURE__*/
              regeneratorRuntime.mark(function _callee7(query) {
                return regeneratorRuntime.wrap(function _callee7$(_context7) {
                  while (1) {
                    switch (_context7.prev = _context7.next) {
                      case 0:
                        if (!(query.queryGroup !== queryGroup)) {
                          _context7.next = 2;
                          break;
                        }

                        return _context7.abrupt("return");

                      case 2:
                        if (!(variables === false && query.variablesHash)) {
                          _context7.next = 4;
                          break;
                        }

                        return _context7.abrupt("return");

                      case 4:
                        if (!(variablesHash && query.variablesHash !== variablesHash)) {
                          _context7.next = 6;
                          break;
                        }

                        return _context7.abrupt("return");

                      case 6:
                        _context7.next = 8;
                        return query.fetch({
                          force: force
                        });

                      case 8:
                      case "end":
                        return _context7.stop();
                    }
                  }
                }, _callee7);
              }));

              return function (_x3) {
                return _ref15.apply(this, arguments);
              };
            }());
            _context8.next = 7;
            return Promise.all(queryPromises);

          case 7:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  }));
  return _refetchQuery.apply(this, arguments);
}

function useMutation(mutationFn) {
  var _ref9 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      refetchQueries = _ref9.refetchQueries;

  var _React$useState3 = React.useState(null),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      data = _React$useState4[0],
      setData = _React$useState4[1];

  var _React$useState5 = React.useState(null),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      error = _React$useState6[0],
      setError = _React$useState6[1];

  var _React$useState7 = React.useState(false),
      _React$useState8 = _slicedToArray(_React$useState7, 2),
      isLoading = _React$useState8[0],
      setIsLoading = _React$useState8[1];

  var mutationFnRef = React.useRef();
  mutationFnRef.current = mutationFn;
  var mutate = React.useCallback(
  /*#__PURE__*/
  function () {
    var _ref10 = _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee6(variables) {
      var _ref11,
          _ref11$throwOnError,
          throwOnError,
          updateQuery,
          _ref11$waitForRefetch,
          waitForRefetchQueries,
          res,
          refetchPromises,
          _args6 = arguments;

      return regeneratorRuntime.wrap(function _callee6$(_context6) {
        while (1) {
          switch (_context6.prev = _context6.next) {
            case 0:
              _ref11 = _args6.length > 1 && _args6[1] !== undefined ? _args6[1] : {}, _ref11$throwOnError = _ref11.throwOnError, throwOnError = _ref11$throwOnError === void 0 ? false : _ref11$throwOnError, updateQuery = _ref11.updateQuery, _ref11$waitForRefetch = _ref11.waitForRefetchQueries, waitForRefetchQueries = _ref11$waitForRefetch === void 0 ? false : _ref11$waitForRefetch;
              setIsLoading(true);
              setError(null);
              _context6.prev = 3;
              _context6.next = 6;
              return mutationFnRef.current(variables);

            case 6:
              res = _context6.sent;
              setData(res);

              if (!refetchQueries) {
                _context6.next = 13;
                break;
              }

              refetchPromises = refetchQueries.map(function (queryKey) {
                return refetchQuery(queryKey, {
                  force: true
                });
              });

              if (!waitForRefetchQueries) {
                _context6.next = 13;
                break;
              }

              _context6.next = 13;
              return Promise.all(refetchPromises);

            case 13:
              if (updateQuery) {
                setQueryData(updateQuery, res, {
                  shouldRefetch: false
                });
              }

              return _context6.abrupt("return", res);

            case 17:
              _context6.prev = 17;
              _context6.t0 = _context6["catch"](3);
              setError(_context6.t0);

              if (!throwOnError) {
                _context6.next = 22;
                break;
              }

              throw _context6.t0;

            case 22:
              _context6.prev = 22;
              setIsLoading(false);
              return _context6.finish(22);

            case 25:
            case "end":
              return _context6.stop();
          }
        }
      }, _callee6, null, [[3, 17, 22, 25]]);
    }));

    return function (_x2) {
      return _ref10.apply(this, arguments);
    };
  }(), [refetchQueries]);
  return [mutate, {
    data: data,
    isLoading: isLoading,
    error: error
  }];
}
function _useQueries() {
  var _React$useState9 = React.useState({
    queries: queries
  }),
      _React$useState10 = _slicedToArray(_React$useState9, 2),
      state = _React$useState10[0],
      setState = _React$useState10[1];

  React.useEffect(function () {
    var fn = function fn() {
      setState({
        queries: queries
      });
    };

    globalStateListeners.push(fn);
    return function () {
      globalStateListeners = globalStateListeners.filter(function (d) {
        return d !== fn;
      });
    };
  }, []);
  return state.queries;
}
function useIsFetching() {
  var queries = _useQueries();

  return React.useMemo(function () {
    return queries.some(function (query) {
      return query.isFetching;
    });
  }, [queries]);
}
function setQueryData(userQueryKey, updater) {
  var _ref12 = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
      _ref12$shouldRefetch = _ref12.shouldRefetch,
      shouldRefetch = _ref12$shouldRefetch === void 0 ? true : _ref12$shouldRefetch;

  var _getQueryInfo3 = getQueryInfo(userQueryKey),
      _getQueryInfo4 = _slicedToArray(_getQueryInfo3, 1),
      queryHash = _getQueryInfo4[0];

  if (!queryHash) {
    return;
  }

  var query = queries.find(function (d) {
    return d.queryHash === queryHash;
  });
  console.log(userQueryKey, updater);
  query.setData(updater);

  if (shouldRefetch) {
    return refetchQuery(userQueryKey);
  }
}
function refetchAllQueries() {
  return _refetchAllQueries.apply(this, arguments);
}

function _refetchAllQueries() {
  _refetchAllQueries = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee10() {
    var _ref13,
        force,
        promises,
        _args10 = arguments;

    return regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            _ref13 = _args10.length > 0 && _args10[0] !== undefined ? _args10[0] : {}, force = _ref13.force;
            promises = queries.map(
            /*#__PURE__*/
            function () {
              var _ref16 = _asyncToGenerator(
              /*#__PURE__*/
              regeneratorRuntime.mark(function _callee9(query) {
                return regeneratorRuntime.wrap(function _callee9$(_context9) {
                  while (1) {
                    switch (_context9.prev = _context9.next) {
                      case 0:
                        if (!(force || query.isStale)) {
                          _context9.next = 3;
                          break;
                        }

                        _context9.next = 3;
                        return query.fetch();

                      case 3:
                      case "end":
                        return _context9.stop();
                    }
                  }
                }, _callee9);
              }));

              return function (_x4) {
                return _ref16.apply(this, arguments);
              };
            }());
            _context10.next = 4;
            return Promise.all(promises);

          case 4:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  }));
  return _refetchAllQueries.apply(this, arguments);
}

function getQueryInfo(queryKey) {
  if (!queryKey) {
    return [];
  }

  if (typeof queryKey === 'function') {
    try {
      return getQueryInfo(queryKey());
    } catch (_unused) {
      return [];
    }
  }

  if (Array.isArray(queryKey)) {
    var _queryKey = _slicedToArray(queryKey, 2),
        id = _queryKey[0],
        variables = _queryKey[1];

    var variablesIsObject = isObject(variables);

    if (process.env.NODE_ENV !== 'production') {
      if (typeof id !== 'string' || variables && !variablesIsObject) {
        console.warn('Tuple queryKey:', queryKey);
        throw new Error("Tuple query keys must be of type [string, object]. You have passed [".concat(_typeof(id), ", and ").concat(_typeof(variables), "]"));
      }
    }

    var variablesHash = variablesIsObject ? sortedStringify(variables) : '';
    return ["".concat(id).concat(variablesHash ? "_".concat(variablesHash, "}") : ''), id, variablesHash, variables];
  }

  return [queryKey, queryKey];
}

function sortedStringifyReplacer(_, value) {
  return isObject(value) ? Object.assign.apply(Object, [{}].concat(_toConsumableArray(Object.keys(value).sort(function (keyA, keyB) {
    return keyA > keyB ? 1 : keyB > keyA ? -1 : 0;
  }).map(function (key) {
    return _defineProperty({}, key, value[key]);
  })))) : value;
}

function sortedStringify(obj) {
  return JSON.stringify(obj, sortedStringifyReplacer);
}

function isObject(a) {
  return a && a !== null && _typeof(a) === 'object';
}

function isDocumentVisible() {
  if (typeof document.visibilityState !== 'undefined') {
    return document.visibilityState === 'visible' || document.visibilityState === 'prerender';
  } // always assume it's visible


  return true;
}

function isOnline() {
  if (typeof navigator.onLine !== 'undefined') {
    return navigator.onLine;
  } // always assume it's online


  return true;
}

function useGetLatest(obj) {
  var ref = React.useRef();
  ref.current = obj;
  return React.useCallback(function () {
    return ref.current;
  }, []);
}

export { _useQueries, refetchAllQueries, refetchQuery, setQueryData, useIsFetching, useMutation, useQuery, useReactQueryConfig };
//# sourceMappingURL=index.es.js.map
